# Art from the Machine

## Overview

**ArsMachina** is a Python package that infuses modern **machine‑learning** techniques into **visual‑effects (VFX)** and digital‑art pipelines. Whether you are a VFX artist looking to automate labor‑intensive tasks or a technical director eager to prototype generative tools, ArsMachina delivers a friendly, modular toolbox for creating art and beauty *from the machine*.

With an emphasis on usability, extensibility, and GPU performance, `arsmachina` provides ready‑made operators, utilities, and tutorials that make it easy to weave ML into Houdini, Blender, Nuke, and other industry staples.

---

## Features

* **Pre‑built Models & Utilities** – Object detection, image segmentation, latent‑diffusion style transfer, and more, tuned for VFX needs.
* **Seamless DCC Integration** – Drop‑in wrappers for Houdini TOPs, Blender Python, and Nuke Gizmos.
* **GPU Acceleration** – Optimised kernels using PyTorch + CUDA so you spend time iterating, not waiting.
* **Tutorials & Example Notebooks** – Hands‑on guides that walk you from "Hello Tensor" to production‑ready FX shots.
* **Extensible Architecture** – Clear entry points for plugging in your own datasets, models, and node flavours.

---

## Why ArsMachina?

Machine learning has opened new creative frontiers—auto‑rotoscoping entire plates, synthesising photoreal textures, or animating crowds at the click of a button. `arsmachina` aims to:

* **Empower VFX professionals** with accessible ML primitives.
* **Provide a playground** for experimenting with generative and analytical techniques.
* **Lower the barrier to entry** so artists can focus on storytelling instead of boilerplate code.

---

## Getting Started

### Installation

Clone the repository and install locally:

```bash
git clone https://github.com/suhailphotos/ArsMachina.git
cd ArsMachina
pip install .
```

or add it to a Poetry‑managed project:

```bash
poetry add arsmachina
```

> **Python ≥ 3.12** and a recent CUDA‑enabled GPU are recommended for full functionality.

---

## Resources

* **Documentation** – API reference and guides live in the `docs/` folder.
* **Examples** – Real‑world notebooks reside in the upcoming course repository `ml4Vfx`.
* **Community** – Open a Discussion or file an Issue—contributions and ideas are welcome!

---

## Contributing

Bug fixes, new operators, and tutorial notebooks are all appreciated. Please read `CONTRIBUTING.md` for coding standards and a quick start on setting up a dev environment.

---

## License

Released under the MIT License. See `LICENSE` for details.

---

## Stay Connected

* **Author**  Suhail
* **GitHub**  [https://github.com/suhailphotos/ArsMachina](https://github.com/suhailphotos/ArsMachina)

